@@ -20,19 +20,20 @@ import six
 from landlab import (  # for type tests
     BAD_INDEX_VALUE,
     Component,
+    FieldError,
+    NetworkModelGrid,
     RasterModelGrid,
     VoronoiDelaunayGrid,
 )
 from landlab.components.flow_accum import flow_accum_bw, flow_accum_to_n
 from landlab.core.messages import warning_message
-from landlab.utils.return_array import return_array_at_node
 from landlab.core.utils import as_id_array
+from landlab.utils.return_array import return_array_at_node
 
 
 class FlowAccumulator(Component):
 
-    """
-    Component to accumulate flow and calculate drainage area.
+    """Component to accumulate flow and calculate drainage area.
 
     This is accomplished by first finding flow directions by a user-specified
     method and then calculating the drainage area and discharge.
@@ -57,7 +58,7 @@ class FlowAccumulator(Component):
             IDs: *'flow__upstream_node_order'*
         -  Node array of all but the first element of the delta data structure:
             *flow__data_structure_delta*. The first element is always zero.
-        -  Link array of the D data structure: *flow__data_structure_D*
+        -  At Grid: D data structure: *flow__data_structure_D*
 
     The FlowDirector component will add additional ModelGrid fields.
     DirectToOne methods(Steepest/D4 and D8) and DirectToMany(DINF and MFD) use
@@ -80,6 +81,8 @@ class FlowAccumulator(Component):
             *'topographic__steepest_slope'* This array is 2D for RouteToMany
             methods and has the shape (n-nodes x max number of receivers).
         -  Boolean node array of all local lows: *'flow__sink_flag'*
+        -  Link array identifing if flow goes with (1) or against (-1) the link
+           direction: *'flow_link_direction'*
 
     The primary method of this class is :func:`run_one_step`.
 
@@ -123,7 +126,7 @@ class FlowAccumulator(Component):
     >>> import numpy as np
     >>> from landlab import RasterModelGrid
     >>> from landlab.components import FlowAccumulator
-    >>> mg = RasterModelGrid((3,3), spacing=(1, 1))
+    >>> mg = RasterModelGrid((3,3))
     >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
     >>> _ = mg.add_field('topographic__elevation',
     ...                  mg.node_x + mg.node_y,
@@ -142,20 +145,29 @@ class FlowAccumulator(Component):
     following four methods are all equivalent. First, we can pass the entire
     name of a flow director as a string to the argument `flow_director`:
 
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                      flow_director='FlowDirectorSteepest')
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director='FlowDirectorSteepest'
+    ... )
 
     Second, we can pass just the method name as a string to the argument
     `flow_director`:
 
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                      flow_director='Steepest')
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director='Steepest'
+    ... )
 
     Third, we can import a FlowDirector component from Landlab and pass it to
     `flow_director`:
     >>> from landlab.components import FlowDirectorSteepest
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                      flow_director=FlowDirectorSteepest)
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ... )
 
     Finally, we can instantiate a FlowDirector component and pass this
     instantiated version to `flow_director`. You might want to do this if you
@@ -163,8 +175,11 @@ class FlowAccumulator(Component):
     time loop and then want to use the same flow director within the loop.
 
     >>> fd = FlowDirectorSteepest(mg, 'topographic__elevation')
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                      flow_director=FlowDirectorSteepest)
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ... )
 
     Now let's look at what FlowAccumulator does. Even before we run
     FlowAccumulator it has the property `surface_values` that stores the values
@@ -175,18 +190,23 @@ class FlowAccumulator(Component):
 
     Now let's make a more complicated elevation grid for the next examples.
 
-    >>> mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    >>> mg = RasterModelGrid((5, 4))
     >>> topographic__elevation = np.array([0.,  0.,  0., 0.,
     ...                                    0., 21., 10., 0.,
     ...                                    0., 31., 20., 0.,
     ...                                    0., 32., 30., 0.,
     ...                                    0.,  0.,  0., 0.])
-    >>> _ = mg.add_field('node',
-    ...                    'topographic__elevation',
-    ...                    topographic__elevation)
+    >>> _ = mg.add_field(
+    ...     'node',
+    ...     'topographic__elevation',
+    ...     topographic__elevation
+    ... )
     >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                        flow_director=FlowDirectorSteepest)
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ...      )
     >>> fa.run_one_step()
     >>> mg.at_node['flow__receiver_node'] # doctest: +NORMALIZE_WHITESPACE
     array([ 0,  1,  2,  3,
@@ -203,19 +223,28 @@ class FlowAccumulator(Component):
 
     Now let's change the cell area (100.) and the runoff rates:
 
-    >>> mg = RasterModelGrid((5, 4), spacing=(10., 10))
+    >>> mg = RasterModelGrid((5, 4), xy_spacing=(10., 10))
 
     Put the data back into the new grid.
 
-    >>> _ = mg.add_field('node',
-    ...                    'topographic__elevation',
-    ...                    topographic__elevation)
+    >>> _ = mg.add_field(
+    ...     'node',
+    ...     'topographic__elevation',
+    ...     topographic__elevation
+    ... )
     >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                        flow_director=FlowDirectorSteepest)
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ...      )
     >>> runoff_rate = np.arange(mg.number_of_nodes, dtype=float)
-    >>> rnff = mg.add_field('node', 'water__unit_flux_in', runoff_rate,
-    ...                  noclobber=False)
+    >>> rnff = mg.add_field(
+    ...        'node',
+    ...        'water__unit_flux_in',
+    ...        runoff_rate,
+    ...        noclobber=False
+    ... )
     >>> fa.run_one_step()
     >>> mg.at_node['surface_water__discharge'] # doctest: +NORMALIZE_WHITESPACE
     array([    0.,   500.,  5200.,     0.,
@@ -254,16 +283,21 @@ class FlowAccumulator(Component):
               0.,    0.,    0.,    0.])
 
     The FlowAccumulator component will work for both raster grids and irregular
-    grids. For the example we will use a Hexagonal Model Grid, a special type of
-    Voroni Grid that has regularly spaced hexagonal cells.
+    grids. For the example we will use a Hexagonal Model Grid, a special type
+    of Voroni Grid that has regularly spaced hexagonal cells.
 
     >>> from landlab import HexModelGrid
-    >>> hmg = HexModelGrid(5,3)
-    >>> _ = hmg.add_field('topographic__elevation',
-    ...                   hmg.node_x + np.round(hmg.node_y),
-    ...                   at = 'node')
-    >>> fa = FlowAccumulator(hmg, 'topographic__elevation',
-    ...                      flow_director=FlowDirectorSteepest)
+    >>> hmg = HexModelGrid(5,3, xy_of_lower_left=(-1., 0.))
+    >>> _ = hmg.add_field(
+    ...     'topographic__elevation',
+    ...     hmg.node_x + np.round(hmg.node_y),
+    ...     at = 'node'
+    ...     )
+    >>> fa = FlowAccumulator(
+    ...      hmg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ... )
     >>> fa.surface_values
     array([ 0. ,  1. ,  2. ,
             0.5,  1.5,  2.5,  3.5,
@@ -278,14 +312,19 @@ class FlowAccumulator(Component):
     For example, in the case of a raster grid, FlowDirectorMFD can use only
     orthogonal links, or it can use both orthogonal and diagonal links.
 
-    >>> mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    >>> mg = RasterModelGrid((5, 5))
     >>> topographic__elevation = mg.node_y+mg.node_x
-    >>> _ = mg.add_field('node',
-    ...                  'topographic__elevation',
-    ...                   topographic__elevation)
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                      flow_director='MFD',
-    ...                      diagonals = True)
+    >>> _ = mg.add_field(
+    ...     'node',
+    ...     'topographic__elevation',
+    ...     topographic__elevation
+    ... )
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director='MFD',
+    ...      diagonals = True
+    ... )
     >>> fa.run_one_step()
     >>> mg.at_node['flow__receiver_node'] # doctest: +NORMALIZE_WHITESPACE
     array([[ 0, -1, -1, -1, -1, -1, -1, -1],
@@ -338,12 +377,17 @@ class FlowAccumulator(Component):
     Next, let's set the dx spacing such that each cell has an area of one.
 
     >>> dx=(2./(3.**0.5))**0.5
-    >>> hmg = HexModelGrid(5,3, dx)
-    >>> _ = hmg.add_field('topographic__elevation',
-    ...                     hmg.node_x**2 + np.round(hmg.node_y)**2,
-    ...                     at = 'node')
-    >>> fa = FlowAccumulator(hmg, 'topographic__elevation',
-    ...                        flow_director=FlowDirectorSteepest)
+    >>> hmg = HexModelGrid(5,3, dx, xy_of_lower_left=(-1.0745, 0.))
+    >>> _ = hmg.add_field(
+    ...     'topographic__elevation',
+    ...     hmg.node_x**2 + np.round(hmg.node_y)**2,
+    ...     at = 'node'
+    ... )
+    >>> fa = FlowAccumulator(
+    ...      hmg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ... )
     >>> fa.run_one_step()
     >>> hmg.at_node['flow__receiver_node'] # doctest: +NORMALIZE_WHITESPACE
     array([ 0,  1,  2,
@@ -360,15 +404,20 @@ class FlowAccumulator(Component):
 
     Now let's change the cell area (100.) and the runoff rates:
 
-    >>> hmg = HexModelGrid(5,3, dx*10.)
+    >>> hmg = HexModelGrid(5,3, dx*10., xy_of_lower_left=(-10.745, 0.))
 
     Put the data back into the new grid.
 
-    >>> _ = hmg.add_field('topographic__elevation',
-    ...                     hmg.node_x**2 + np.round(hmg.node_y)**2,
-    ...                     at = 'node')
-    >>> fa = FlowAccumulator(hmg, 'topographic__elevation',
-    ...                        flow_director=FlowDirectorSteepest)
+    >>> _ = hmg.add_field(
+    ...     'topographic__elevation',
+    ...     hmg.node_x**2 + np.round(hmg.node_y)**2,
+    ...     at = 'node'
+    ... )
+    >>> fa = FlowAccumulator(
+    ...      hmg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ...      )
     >>> fa.run_one_step()
     >>> hmg.at_node['surface_water__discharge']
     array([ 500.,    0.,    0.,
@@ -379,7 +428,7 @@ class FlowAccumulator(Component):
 
     Next, let's see what happens to a raster grid when there is a depression.
 
-    >>> mg = RasterModelGrid((7, 7), 0.5)
+    >>> mg = RasterModelGrid((7, 7), xy_spacing=0.5)
     >>> z = mg.add_field('node', 'topographic__elevation', mg.node_x.copy())
     >>> z += 0.01 * mg.node_y
     >>> mg.at_node['topographic__elevation'].reshape(mg.shape)[2:5, 2:5] *= 0.1
@@ -395,8 +444,11 @@ class FlowAccumulator(Component):
            [ 0.02  ,  0.52  ,  0.102 ,  0.152 ,  0.202 ,  2.52  ,  3.02  ],
            [ 0.025 ,  0.525 ,  1.025 ,  1.525 ,  2.025 ,  2.525 ,  3.025 ],
            [ 0.03  ,  0.53  ,  1.03  ,  1.53  ,  2.03  ,  2.53  ,  3.03  ]])
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                        flow_director=FlowDirectorSteepest)
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest
+    ...      )
     >>> fa.run_one_step()  # the flow "gets stuck" in the hole
     >>> mg.at_node['flow__receiver_node'].reshape(mg.shape)
     array([[ 0,  1,  2,  3,  4,  5,  6],
@@ -480,13 +532,16 @@ class FlowAccumulator(Component):
     and the depression finder with one call. For this example, we will pass the
     class DepressionFinderAndRouter to the parameter `depression_finder`.
 
-    >>> mg = RasterModelGrid((7, 7), 0.5)
+    >>> mg = RasterModelGrid((7, 7), xy_spacing=0.5)
     >>> z = mg.add_field('node', 'topographic__elevation', mg.node_x.copy())
     >>> z += 0.01 * mg.node_y
     >>> mg.at_node['topographic__elevation'].reshape(mg.shape)[2:5, 2:5] *= 0.1
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                        flow_director='FlowDirectorD8',
-    ...                        depression_finder=DepressionFinderAndRouter)
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director='FlowDirectorD8',
+    ...      depression_finder=DepressionFinderAndRouter
+    ... )
     >>> fa.run_one_step()
 
     This has the same effect of first calling the accumulator and then calling
@@ -541,11 +596,33 @@ class FlowAccumulator(Component):
     through FlowAccumulator, we can pass this keyword argument to the
     DepressionFinderAndRouter component.
 
-    >>> fa = FlowAccumulator(mg, 'topographic__elevation',
-    ...                      flow_director=FlowDirectorSteepest,
-    ...                      depression_finder=DepressionFinderAndRouter,
-    ...                      routing='D4')
+    >>> fa = FlowAccumulator(
+    ...      mg,
+    ...      'topographic__elevation',
+    ...      flow_director=FlowDirectorSteepest,
+    ...      depression_finder=DepressionFinderAndRouter,
+    ...      routing='D4'
+    ... )
 
+    FlowAccumulator was designed to work with all types of grids. However,
+    NetworkModelGrid's have no cell area. Thus, in order for FlowAccumulator to
+    this type of grid, an at-node array called ``cell_area_at_node`` must be
+    present.
+
+    >>> from landlab.grid.network import NetworkModelGrid
+    >>> y_of_node = (0, 1, 2, 2)
+    >>> x_of_node = (0, 0, -1, 1)
+    >>> nodes_at_link = ((1, 0), (2, 1), (3, 1))
+    >>> nmg = NetworkModelGrid((y_of_node, x_of_node), nodes_at_link)
+    >>> area = nmg.add_ones('node', 'cell_area_at_node')
+    >>> z = nmg.add_field(
+    ...     'topographic__elevation',
+    ...     nmg.x_of_node + nmg.y_of_node,
+    ...     at = 'node')
+    >>> fa = FlowAccumulator(nmg)
+    >>> fa.run_one_step()
+    >>> nmg.at_node['flow__receiver_node']
+    array([0, 0, 2, 1])
     """
 
     _name = "FlowAccumulator"
@@ -582,7 +659,7 @@ class FlowAccumulator(Component):
         "flow__upstream_node_order": "node",
         "flow__nodes_not_in_stack": "grid",
         "flow__data_structure_delta": "node",
-        "flow__data_structure_D": "link",
+        "flow__data_structure_D": "grid",
     }
     _var_doc = {
         "topographic__elevation": "Land surface topographic elevation",
@@ -598,8 +675,8 @@ class FlowAccumulator(Component):
         "flow__data_structure_delta": "Node array containing the elements delta[1:] of the data "
         'structure "delta" used for construction of the downstream-to-'
         "upstream node array",
-        "flow__data_structure_D": "Link array containing the data structure D used for construction"
-        "of the downstream-to-upstream node array",
+        "flow__data_structure_D": "Array containing the data structure D used for construction"
+        "of the downstream-to-upstream node array. Stored at Grid.",
         "flow__nodes_not_in_stack": "Boolean value indicating if there are any nodes that have not yet"
         "been added to the stack stored in flow__upstream_node_order.",
     }
@@ -613,12 +690,12 @@ class FlowAccumulator(Component):
         depression_finder=None,
         **kwargs
     ):
-        """
-        Initialize the FlowAccumulator component.
+        """Initialize the FlowAccumulator component.
 
-        Saves the grid, tests grid type, tests imput types and compatability
-        for the flow_director and depression_finder keyword arguments, tests
-        the argument of runoff_rate, and initializes new fields.
+        Saves the grid, tests grid type, tests imput types and
+        compatability for the flow_director and depression_finder
+        keyword arguments, tests the argument of runoff_rate, and
+        initializes new fields.
         """
         super(FlowAccumulator, self).__init__(grid)
         # Keep a local reference to the grid
@@ -627,7 +704,7 @@ class FlowAccumulator(Component):
         # Grid type testing
         self._is_raster = isinstance(self._grid, RasterModelGrid)
         self._is_Voroni = isinstance(self._grid, VoronoiDelaunayGrid)
-
+        self._is_Network = isinstance(self._grid, NetworkModelGrid)
         self.kwargs = kwargs
         # STEP 1: Testing of input values, supplied either in function call or
         # as part of the grid.
@@ -637,8 +714,18 @@ class FlowAccumulator(Component):
         self.surface = surface
         self.surface_values = return_array_at_node(grid, surface)
 
-        node_cell_area = self._grid.cell_area_at_node.copy()
-        node_cell_area[self._grid.closed_boundary_nodes] = 0.
+        if self._is_Network:
+            try:
+                node_cell_area = self._grid.at_node["cell_area_at_node"]
+            except FieldError:
+                raise FieldError(
+                    "In order for the FlowAccumulator to work, the "
+                    "grid must have an at-node field called "
+                    "cell_area_at_node."
+                )
+        else:
+            node_cell_area = self._grid.cell_area_at_node.copy()
+            node_cell_area[self._grid.closed_boundary_nodes] = 0.
 
         self.node_cell_area = node_cell_area
 
@@ -689,27 +776,19 @@ class FlowAccumulator(Component):
         else:
             self.delta_structure = grid.at_node["flow__data_structure_delta"]
 
-        if "flow__data_structure_D" not in grid.at_link:
-            if self.flow_director.to_n_receivers == "many" and self._is_raster:
-                # needs to be BAD_INDEX_VALUE
-                self.D_structure = grid.add_field(
-                    "flow__data_structure_D",
-                    BAD_INDEX_VALUE
-                    * np.ones((self._grid.number_of_links, 2), dtype=int),
-                    at="link",
-                    dtype=int,
-                    noclobber=False,
-                )
-            else:
-                # needs to be BAD_INDEX_VALUE
-                self.D_structure = grid.add_field(
-                    "flow__data_structure_D",
-                    BAD_INDEX_VALUE * grid.ones(at="link"),
-                    at="link",
-                    dtype=int,
-                )
-        else:
-            self.D_structure = grid.at_link["flow__data_structure_D"]
+        try:
+            D = BAD_INDEX_VALUE * grid.ones(at="link", dtype=int)
+            D_structure = np.array([D], dtype=object)
+            self.D_structure = grid.add_field(
+                "flow__data_structure_D",
+                D_structure,
+                at="grid",
+                dtype=object,
+                noclobber=False,
+            )
+
+        except FieldError:
+            self.D_structure = grid.at_grid["flow__data_structure_D"]
 
         self.nodes_not_in_stack = True
 
@@ -728,6 +807,75 @@ class FlowAccumulator(Component):
         """Return the upstream node order (drainage stack)."""
         return self._grid["node"]["flow__upstream_node_order"]
 
+    def link_order_upstream(self):
+        """Return the upstream order of active links.
+
+        Examples
+        --------
+        >>> from landlab import RasterModelGrid
+        >>> from landlab.components import FlowAccumulator
+        >>> mg = RasterModelGrid((5, 5))
+        >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
+        >>> _ = mg.add_field(
+        ...     'topographic__elevation',
+        ...     mg.node_x + mg.node_y,
+        ...     at = 'node'
+        ...     )
+        >>> fa = FlowAccumulator(mg, 'topographic__elevation')
+        >>> fa.run_one_step()
+        >>> fa.link_order_upstream()
+        array([ 5, 14, 23,  6, 15, 24,  7, 16, 25])
+
+        This also works for route-to-many methods
+
+        >>> mg = RasterModelGrid((5, 5))
+        >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
+        >>> _ = mg.add_field(
+        ...     'topographic__elevation',
+        ...     mg.node_x + mg.node_y,
+        ...     at = 'node'
+        ... )
+        >>> fa = FlowAccumulator(mg,
+        ...      'topographic__elevation',
+        ...      flow_director='MFD')
+        >>> fa.run_one_step()
+        >>> fa.link_order_upstream()
+        array([ 5, 14, 10,  6, 11,  7, 23, 19, 15, 20, 16, 28, 24, 29, 25])
+        """
+        downstream_links = self._grid["node"]["flow__link_to_receiver_node"][
+            self.node_order_upstream
+        ]
+        out = downstream_links.flatten()
+        return out[out != BAD_INDEX_VALUE]
+
+    def headwater_nodes(self):
+        """Return the headwater nodes.
+
+        These are nodes that contribute flow and have no upstream nodes.
+
+        Examples
+        --------
+        >>> from numpy.testing import assert_array_equal
+        >>> from landlab import RasterModelGrid
+        >>> from landlab.components import FlowAccumulator
+        >>> mg = RasterModelGrid((5, 5))
+        >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
+        >>> _ = mg.add_field(
+        ...     'topographic__elevation',
+        ...     mg.node_x + mg.node_y,
+        ...     at = 'node'
+        ... )
+        >>> fa = FlowAccumulator(mg, 'topographic__elevation')
+        >>> fa.run_one_step()
+        >>> assert_array_equal(fa.headwater_nodes(), np.array([16, 17, 18]))
+        """
+        delta = np.concatenate(([0], self.delta_structure))
+        num_donors = np.diff(delta)
+        # note closed nodes have a value of 1 here since they flow to
+        # themselves
+        source_nodes = np.where(num_donors == 0)[0]
+        return source_nodes
+
     def _test_water_inputs(self, grid, runoff_rate):
         """Test inputs for runoff_rate and water__unit_flux_in."""
         if "water__unit_flux_in" not in grid.at_node:
@@ -951,8 +1099,8 @@ class FlowAccumulator(Component):
             self.depression_finder = None
 
     def accumulate_flow(self, update_flow_director=True):
-        """
-        Function to make FlowAccumulator calculate drainage area and discharge.
+        """Function to make FlowAccumulator calculate drainage area and
+        discharge.
 
         Running run_one_step() results in the following to occur:
             1. Flow directions are updated (unless update_flow_director is set
@@ -987,6 +1135,10 @@ class FlowAccumulator(Component):
             if self.depression_finder_provided is not None:
                 self.depression_finder.map_depressions()
 
+                # if FlowDirectorSteepest is used, update the link directions
+                if self.flow_director._name is "FlowDirectorSteepest":
+                    self.flow_director._determine_link_directions()
+
             # step 3. Stack, D, delta construction
             nd = as_id_array(flow_accum_bw._make_number_of_donors_array(r))
             delta = as_id_array(flow_accum_bw._make_delta_array(nd))
@@ -996,7 +1148,7 @@ class FlowAccumulator(Component):
             # put these in grid so that depression finder can use it.
             # store the generated data in the grid
             self._grid["node"]["flow__data_structure_delta"][:] = delta[1:]
-            self._grid["link"]["flow__data_structure_D"][:len(D)] = D
+            self._grid["grid"]["flow__data_structure_D"] = np.array([D], dtype=object)
             self._grid["node"]["flow__upstream_node_order"][:] = s
 
             # step 4. Accumulate (to one or to N depending on direction method)
@@ -1007,27 +1159,18 @@ class FlowAccumulator(Component):
             p = self._grid["node"]["flow__receiver_proportions"]
 
             # step 3. Stack, D, delta construction
-            nd = as_id_array(
-                flow_accum_to_n._make_number_of_donors_array_to_n(r, p)
-            )
+            nd = as_id_array(flow_accum_to_n._make_number_of_donors_array_to_n(r, p))
             delta = as_id_array(flow_accum_to_n._make_delta_array_to_n(nd))
-            D = as_id_array(
-                flow_accum_to_n._make_array_of_donors_to_n(r, p, delta)
-            )
+            D = as_id_array(flow_accum_to_n._make_array_of_donors_to_n(r, p, delta))
             s = as_id_array(flow_accum_to_n.make_ordered_node_array_to_n(r, p))
 
             # put theese in grid so that depression finder can use it.
             # store the generated data in the grid
             self._grid["node"]["flow__data_structure_delta"][:] = delta[1:]
-
-            if self._is_raster:
-                tempD = BAD_INDEX_VALUE * np.ones(
-                    (self._grid.number_of_links * 2))
-                tempD[: len(D)] = D
-                self._grid["link"]["flow__data_structure_D"][
-                    :] = tempD.reshape((self._grid.number_of_links, 2))
-            else:
-                self._grid["link"]["flow__data_structure_D"][:len(D)] = D
+            self._grid["grid"]["flow__data_structure_D"][0] = np.array(
+                [D], dtype=object
+            )
+            self._grid["node"]["flow__upstream_node_order"][:] = s
             self._grid["node"]["flow__upstream_node_order"][:] = s
 
             # step 4. Accumulate (to one or to N depending on direction method)
@@ -1036,30 +1179,27 @@ class FlowAccumulator(Component):
         return (a, q)
 
     def _accumulate_A_Q_to_one(self, s, r):
-        """
-        Accumulate area and discharge for a route-to-one scheme. Note this
-        can be overridden in inherited components.
+        """Accumulate area and discharge for a route-to-one scheme.
+
+        Note this can be overridden in inherited components.
         """
         a, q = flow_accum_bw.find_drainage_area_and_discharge(
-            s, r, self.node_cell_area,
-            self._grid.at_node["water__unit_flux_in"]
+            s, r, self.node_cell_area, self._grid.at_node["water__unit_flux_in"]
         )
         return (a, q)
 
     def _accumulate_A_Q_to_n(self, s, r, p):
-        """
-        Accumulate area and discharge for a route-to-many scheme. Note this
-        can be overridden in inherited components.
+        """Accumulate area and discharge for a route-to-many scheme.
+
+        Note this can be overridden in inherited components.
         """
         a, q = flow_accum_to_n.find_drainage_area_and_discharge_to_n(
-            s, r, p, self.node_cell_area,
-            self._grid.at_node["water__unit_flux_in"]
+            s, r, p, self.node_cell_area, self._grid.at_node["water__unit_flux_in"]
         )
         return (a, q)
 
     def run_one_step(self):
-        """
-        Accumulate flow and save to the model grid.
+        """Accumulate flow and save to the model grid.
 
         run_one_step() checks for updated boundary conditions, calculates
         slopes on links, finds baselevel nodes based on the status at node,
