@@ -9,7 +9,7 @@ import numpy as np
 import pytest
 from numpy.testing import assert_array_equal
 
-from landlab import HexModelGrid, RasterModelGrid
+from landlab import FieldError, HexModelGrid, NetworkModelGrid, RasterModelGrid
 from landlab.components import LinearDiffuser
 from landlab.components.flow_accum import FlowAccumulator
 from landlab.components.flow_director import (
@@ -26,7 +26,7 @@ _THIS_DIR = os.path.abspath(os.path.dirname(__file__))
 def test_check_fields():
     """Check to make sure the right fields have been created."""
 
-    mg = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     z = mg.add_field(
         "topographic__elevation", mg.node_x ** 2 + mg.node_y ** 2, at="node"
     )
@@ -43,28 +43,28 @@ def test_check_fields():
 def test_director_adding_methods_are_equivalent_Steepest():
     """Check that different methods to specifying the director are the same."""
 
-    mg0 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg0 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg0.add_field(
         "topographic__elevation", mg0.node_x ** 2 + mg0.node_y ** 2, at="node"
     )
     fa0 = FlowAccumulator(mg0, flow_director="D4")
     fa0.run_one_step()
 
-    mg1 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg1 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg1.add_field(
         "topographic__elevation", mg1.node_x ** 2 + mg1.node_y ** 2, at="node"
     )
     fa1 = FlowAccumulator(mg1, flow_director="Steepest")
     fa1.run_one_step()
 
-    mg2 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg2 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg2.add_field(
         "topographic__elevation", mg2.node_x ** 2 + mg2.node_y ** 2, at="node"
     )
     fa2 = FlowAccumulator(mg2, flow_director=FlowDirectorSteepest)
     fa2.run_one_step()
 
-    mg3 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg3 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg3.add_field(
         "topographic__elevation", mg3.node_x ** 2 + mg3.node_y ** 2, at="node"
     )
@@ -72,39 +72,47 @@ def test_director_adding_methods_are_equivalent_Steepest():
     fa3 = FlowAccumulator(mg3, flow_director=fd)
     fa3.run_one_step()
 
-    for key in mg0.at_node.keys():
-        assert_array_equal(mg0.at_node[key], mg1.at_node[key])
+    for loc in ["node", "link", "grid"]:
+        for key in mg0[loc].keys():
+            if loc == "grid":
+                assert_array_equal(mg0[loc][key][0], mg1[loc][key][0])
 
-        assert_array_equal(mg1.at_node[key], mg2.at_node[key])
+                assert_array_equal(mg1[loc][key][0], mg2[loc][key][0])
 
-        assert_array_equal(mg2.at_node[key], mg3.at_node[key])
+                assert_array_equal(mg2[loc][key][0], mg3[loc][key][0])
+            else:
+                assert_array_equal(mg0[loc][key], mg1[loc][key])
+
+                assert_array_equal(mg1[loc][key], mg2[loc][key])
+
+                assert_array_equal(mg2[loc][key], mg3[loc][key])
 
 
 def test_director_adding_methods_are_equivalent_D8():
     """Check that different methods to specifying the director are the same."""
 
-    mg0 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg0 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg0.add_field(
         "topographic__elevation", mg0.node_x ** 2 + mg0.node_y ** 2, at="node"
     )
     fa0 = FlowAccumulator(mg0, flow_director="D8")
     fa0.run_one_step()
 
-    mg1 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg1 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg1.add_field(
         "topographic__elevation", mg1.node_x ** 2 + mg1.node_y ** 2, at="node"
     )
     fa1 = FlowAccumulator(mg1, flow_director="FlowDirectorD8")
     fa1.run_one_step()
 
-    mg2 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg2 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg2.add_field(
         "topographic__elevation", mg2.node_x ** 2 + mg2.node_y ** 2, at="node"
     )
     fa2 = FlowAccumulator(mg2, flow_director=FlowDirectorD8)
     fa2.run_one_step()
 
-    mg3 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg3 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg3.add_field(
         "topographic__elevation", mg3.node_x ** 2 + mg3.node_y ** 2, at="node"
     )
@@ -112,39 +120,47 @@ def test_director_adding_methods_are_equivalent_D8():
     fa3 = FlowAccumulator(mg3, flow_director=fd)
     fa3.run_one_step()
 
-    for key in mg0.at_node.keys():
-        assert_array_equal(mg0.at_node[key], mg1.at_node[key])
+    for loc in ["node", "link", "grid"]:
+        for key in mg0[loc].keys():
+            if loc == "grid":
+                assert_array_equal(mg0[loc][key][0], mg1[loc][key][0])
 
-        assert_array_equal(mg1.at_node[key], mg2.at_node[key])
+                assert_array_equal(mg1[loc][key][0], mg2[loc][key][0])
 
-        assert_array_equal(mg2.at_node[key], mg3.at_node[key])
+                assert_array_equal(mg2[loc][key][0], mg3[loc][key][0])
+            else:
+                assert_array_equal(mg0[loc][key], mg1[loc][key])
+
+                assert_array_equal(mg1[loc][key], mg2[loc][key])
+
+                assert_array_equal(mg2[loc][key], mg3[loc][key])
 
 
 def test_director_adding_methods_are_equivalent_Dinf():
     """Check that different methods to specifying the director are the same."""
 
-    mg0 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg0 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg0.add_field(
         "topographic__elevation", mg0.node_x ** 2 + mg0.node_y ** 2, at="node"
     )
     fa0 = FlowAccumulator(mg0, flow_director="DINF")
     fa0.run_one_step()
 
-    mg1 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg1 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg1.add_field(
         "topographic__elevation", mg1.node_x ** 2 + mg1.node_y ** 2, at="node"
     )
     fa1 = FlowAccumulator(mg1, flow_director="FlowDirectorDINF")
     fa1.run_one_step()
 
-    mg2 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg2 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg2.add_field(
         "topographic__elevation", mg2.node_x ** 2 + mg2.node_y ** 2, at="node"
     )
     fa2 = FlowAccumulator(mg2, flow_director=FlowDirectorDINF)
     fa2.run_one_step()
 
-    mg3 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg3 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg3.add_field(
         "topographic__elevation", mg3.node_x ** 2 + mg3.node_y ** 2, at="node"
     )
@@ -152,39 +168,47 @@ def test_director_adding_methods_are_equivalent_Dinf():
     fa3 = FlowAccumulator(mg3, flow_director=fd)
     fa3.run_one_step()
 
-    for key in mg0.at_node.keys():
-        assert_array_equal(mg0.at_node[key], mg1.at_node[key])
+    for loc in ["node", "link", "grid"]:
+        for key in mg0[loc].keys():
+            if loc == "grid":
+                assert_array_equal(mg0[loc][key][0], mg1[loc][key][0])
 
-        assert_array_equal(mg1.at_node[key], mg2.at_node[key])
+                assert_array_equal(mg1[loc][key][0], mg2[loc][key][0])
 
-        assert_array_equal(mg2.at_node[key], mg3.at_node[key])
+                assert_array_equal(mg2[loc][key][0], mg3[loc][key][0])
+            else:
+                assert_array_equal(mg0[loc][key], mg1[loc][key])
+
+                assert_array_equal(mg1[loc][key], mg2[loc][key])
+
+                assert_array_equal(mg2[loc][key], mg3[loc][key])
 
 
 def test_director_adding_methods_are_equivalent_MFD():
     """Check that different methods to specifying the director are the same."""
 
-    mg0 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg0 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg0.add_field(
         "topographic__elevation", mg0.node_x ** 2 + mg0.node_y ** 2, at="node"
     )
     fa0 = FlowAccumulator(mg0, flow_director="MFD")
     fa0.run_one_step()
 
-    mg1 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg1 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg1.add_field(
         "topographic__elevation", mg1.node_x ** 2 + mg1.node_y ** 2, at="node"
     )
     fa1 = FlowAccumulator(mg1, flow_director="FlowDirectorMFD")
     fa1.run_one_step()
 
-    mg2 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg2 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg2.add_field(
         "topographic__elevation", mg2.node_x ** 2 + mg2.node_y ** 2, at="node"
     )
     fa2 = FlowAccumulator(mg2, flow_director=FlowDirectorMFD)
     fa2.run_one_step()
 
-    mg3 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg3 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg3.add_field(
         "topographic__elevation", mg3.node_x ** 2 + mg3.node_y ** 2, at="node"
     )
@@ -192,19 +216,27 @@ def test_director_adding_methods_are_equivalent_MFD():
     fa3 = FlowAccumulator(mg3, flow_director=fd)
     fa3.run_one_step()
 
-    for key in mg0.at_node.keys():
-        assert_array_equal(mg0.at_node[key], mg1.at_node[key])
+    for loc in ["node", "link", "grid"]:
+        for key in mg0[loc].keys():
+            if loc == "grid":
+                assert_array_equal(mg0[loc][key][0], mg1[loc][key][0])
 
-        assert_array_equal(mg1.at_node[key], mg2.at_node[key])
+                assert_array_equal(mg1[loc][key][0], mg2[loc][key][0])
 
-        assert_array_equal(mg2.at_node[key], mg3.at_node[key])
+                assert_array_equal(mg2[loc][key][0], mg3[loc][key][0])
+            else:
+                assert_array_equal(mg0[loc][key], mg1[loc][key])
+
+                assert_array_equal(mg1[loc][key], mg2[loc][key])
+
+                assert_array_equal(mg2[loc][key], mg3[loc][key])
 
 
 def test_passing_a_bad_component():
     """Check that a random component can't be a director."""
     from landlab.components import ChiFinder
 
-    mg = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
 
@@ -215,12 +247,12 @@ def test_passing_a_bad_component():
 def test_error_for_to_many_with_depression():
     """Check that an error is thrown when to_many methods started DF."""
 
-    mg0 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg0 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg0.add_field(
         "topographic__elevation", mg0.node_x ** 2 + mg0.node_y ** 2, at="node"
     )
 
-    mg1 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg1 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg1.add_field(
         "topographic__elevation", mg1.node_x ** 2 + mg1.node_y ** 2, at="node"
     )
@@ -250,7 +282,7 @@ def test_fields():
 
     Check that the sizes are also correct.
     """
-    mg = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     fa = FlowAccumulator(mg)
     fa.run_one_step()
@@ -267,9 +299,9 @@ def test_fields():
         "topographic__steepest_slope",
         "water__unit_flux_in",
     ]
-    assert sorted(list(mg.at_link.keys())) == ["flow__data_structure_D"]
+    assert sorted(list(mg.at_grid.keys())) == ["flow__data_structure_D"]
 
-    mg2 = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg2 = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg2.add_field("topographic__elevation", mg2.node_x + mg2.node_y, at="node")
     fa2 = FlowAccumulator(mg2, flow_director="MFD")
     fa2.run_one_step()
@@ -287,7 +319,7 @@ def test_fields():
         "water__unit_flux_in",
     ]
 
-    assert sorted(list(mg2.at_link.keys())) == ["flow__data_structure_D"]
+    assert sorted(list(mg2.at_grid.keys())) == ["flow__data_structure_D"]
 
 
 def test_accumulated_area_closes():
@@ -296,7 +328,7 @@ def test_accumulated_area_closes():
     fds = ["Steepest", "D8", "MFD", "DINF"]
 
     for fd in fds:
-        mg = RasterModelGrid((10, 10), spacing=(1, 1))
+        mg = RasterModelGrid((10, 10), xy_spacing=(1, 1))
         mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
         fa = FlowAccumulator(mg)
         fa.run_one_step()
@@ -309,7 +341,7 @@ def test_accumulated_area_closes():
 
 # def test_passing_unnecessary_kwarg():
 #     """Test that passing a bad kwarg raises a ValueError."""
-#     mg = RasterModelGrid((10,10), spacing=(1, 1))
+#     mg = RasterModelGrid((10,10), xy_spacing=(1, 1))
 #     z = mg.add_field('topographic__elevation', mg.node_x + mg.node_y, at = 'node')
 #     with pytest.raises(ValueError):
 #         FlowAccumulator(mg, bad_kwarg='woo')
@@ -317,7 +349,7 @@ def test_accumulated_area_closes():
 
 def test_specifying_routing_method_wrong():
     """Test specifying incorrect method for routing compatability with DepressionFinderAndRouter."""
-    mg = RasterModelGrid((10, 10), spacing=(1, 1))
+    mg = RasterModelGrid((10, 10), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
 
     with pytest.raises(ValueError):
@@ -332,7 +364,7 @@ def test_specifying_routing_method_wrong():
 
 def test_field_name_array_float_case1():
     """Topography as field, runoff rate as float"""
-    mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    mg = RasterModelGrid((5, 4), xy_spacing=(1, 1))
     topographic__elevation = np.array(
         [
             0.,
@@ -406,7 +438,7 @@ def test_field_name_array_float_case1():
 
 def test_field_name_array_float_case2():
     """Topography as field, runoff rate as field name"""
-    mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    mg = RasterModelGrid((5, 4), xy_spacing=(1, 1))
     topographic__elevation = np.array(
         [
             0.,
@@ -503,7 +535,7 @@ def test_field_name_array_float_case2():
 
 def test_field_name_array_float_case3():
     """Topography as field, runoff rate as array"""
-    mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    mg = RasterModelGrid((5, 4), xy_spacing=(1, 1))
     topographic__elevation = np.array(
         [
             0.,
@@ -599,7 +631,7 @@ def test_field_name_array_float_case3():
 
 def test_field_name_array_float_case4():
     """Topography as array, runoff rate as float"""
-    mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    mg = RasterModelGrid((5, 4), xy_spacing=(1, 1))
     topographic__elevation = np.array(
         [
             0.,
@@ -673,7 +705,7 @@ def test_field_name_array_float_case4():
 
 def test_field_name_array_float_case5():
     """Topography as array, runoff rate as field name"""
-    mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    mg = RasterModelGrid((5, 4), xy_spacing=(1, 1))
     topographic__elevation = np.array(
         [
             0.,
@@ -770,7 +802,7 @@ def test_field_name_array_float_case5():
 
 def test_field_name_array_float_case6():
     """Topography as array, runoff rate as array"""
-    mg = RasterModelGrid((5, 4), spacing=(1, 1))
+    mg = RasterModelGrid((5, 4), xy_spacing=(1, 1))
     topographic__elevation = np.array(
         [
             0.,
@@ -865,7 +897,7 @@ def test_field_name_array_float_case6():
 
 
 def test_flow_accumulator_properties():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     fa = FlowAccumulator(mg)
     fa.run_one_step()
@@ -936,7 +968,7 @@ def test_flow_accumulator_properties():
 
 
 def test_water_discharge_in_supplied():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     mg.add_field("water__discharge_in", mg.node_x + mg.node_y, at="node")
     with pytest.deprecated_call():
@@ -944,14 +976,14 @@ def test_water_discharge_in_supplied():
 
 
 def test_bad_director_name():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     with pytest.raises(ValueError):
         FlowAccumulator(mg, flow_director="spam")
 
 
 def test_bad_director_instance():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     ld = LinearDiffuser(mg, linear_diffusivity=1.)
     with pytest.raises(ValueError):
@@ -959,7 +991,7 @@ def test_bad_director_instance():
 
 
 def test_instantiated_director_with_kwargs():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     fd = FlowDirectorSteepest(mg)
     with pytest.raises(ValueError):
@@ -967,14 +999,14 @@ def test_instantiated_director_with_kwargs():
 
 
 def test_depression_finder_as_bad_string():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     with pytest.raises(ValueError):
         FlowAccumulator(mg, flow_director="D8", depression_finder="spam")
 
 
 def test_depression_finder_as_string():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     FlowAccumulator(
         mg, flow_director="D8", depression_finder="DepressionFinderAndRouter"
@@ -982,14 +1014,14 @@ def test_depression_finder_as_string():
 
 
 def test_depression_finder_as_instance():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     df = DepressionFinderAndRouter(mg)
     FlowAccumulator(mg, flow_director="D8", depression_finder=df)
 
 
 def test_depression_finder_bad_instance():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     ld = LinearDiffuser(mg, linear_diffusivity=1.)
     with pytest.raises(ValueError):
@@ -997,7 +1029,7 @@ def test_depression_finder_bad_instance():
 
 
 def test_instantiated_depression_finder_with_kwargs():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     df = DepressionFinderAndRouter(mg)
     with pytest.raises(ValueError):
@@ -1005,7 +1037,7 @@ def test_instantiated_depression_finder_with_kwargs():
 
 
 def test_depression_finder_bad_uninstantiated_component():
-    mg = RasterModelGrid((5, 5), spacing=(1, 1))
+    mg = RasterModelGrid((5, 5), xy_spacing=(1, 1))
     mg.add_field("topographic__elevation", mg.node_x + mg.node_y, at="node")
     with pytest.raises(ValueError):
         FlowAccumulator(mg, flow_director="D8", depression_finder=LinearDiffuser)
@@ -1025,7 +1057,7 @@ def test_flat_grids_all_directors():
         "FlowDirectorD8",
         "FlowDirectorDINF",
     ]:
-        mg = RasterModelGrid(10, 10)
+        mg = RasterModelGrid((10, 10))
         z = mg.add_zeros("topographic__elevation", at="node")
         fa = FlowAccumulator(mg, flow_director=fd)
         fa.run_one_step()
@@ -1034,3 +1066,13 @@ def test_flat_grids_all_directors():
         true_da[mg.core_nodes] = 1.0
         assert_array_equal(true_da, fa.drainage_area)
         del mg, z, fa
+
+
+def test_nmg_no_cell_area():
+    y_of_node = (0, 1, 2, 2)
+    x_of_node = (0, 0, -1, 1)
+    nodes_at_link = ((1, 0), (2, 1), (3, 1))
+    nmg = NetworkModelGrid((y_of_node, x_of_node), nodes_at_link)
+    nmg.add_field("topographic__elevation", nmg.x_of_node + nmg.y_of_node, at="node")
+    with pytest.raises(FieldError):
+        FlowAccumulator(nmg)
