@@ -1,10 +1,10 @@
 #! /usr/env/python
 
-"""
-flow_director_to_one.py provides a private class to help create FlowDirectors.
+"""flow_director_to_one.py provides a private class to help create
+FlowDirectors.
 
-Provides the _FlowDirectorToOne component which makes sure all model grid
-fields are set up correctly.
+Provides the _FlowDirectorToOne component which makes sure all model
+grid fields are set up correctly.
 """
 import numpy
 
@@ -14,8 +14,7 @@ from landlab.components.flow_director.flow_director import _FlowDirector
 
 class _FlowDirectorToOne(_FlowDirector):
 
-    """
-    Private class for creating components to calculate flow directions.
+    """Private class for creating components to calculate flow directions.
 
     This class is not meant to be used directly in modeling efforts. It
     inherits from the _FlowDirector class and builds on it to provide the
@@ -53,18 +52,22 @@ class _FlowDirectorToOne(_FlowDirector):
     >>> from landlab import RasterModelGrid
     >>> from landlab.components.flow_director.flow_director_to_one import(
     ... _FlowDirectorToOne)
-    >>> mg = RasterModelGrid((3,3), spacing=(1, 1))
+    >>> mg = RasterModelGrid((3,3), xy_spacing=(1, 1))
     >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
-    >>> _ = mg.add_field('topographic__elevation',
-    ...                  mg.node_x + mg.node_y,
-    ...                  at = 'node')
+    >>> _ = mg.add_field(
+    ...     'topographic__elevation',
+    ...     mg.node_x + mg.node_y,
+    ...     at = 'node'
+    ... )
     >>> fd = _FlowDirectorToOne(mg, 'topographic__elevation')
     >>> fd.surface_values
     array([ 0.,  1.,  2.,  1.,  2.,  3.,  2.,  3.,  4.])
     >>> sorted(list(mg.at_node.keys()))
-    ['flow__link_to_receiver_node', 'flow__receiver_node',
-           'flow__sink_flag', 'topographic__elevation',
-           'topographic__steepest_slope']
+    ['flow__link_to_receiver_node',
+     'flow__receiver_node',
+     'flow__sink_flag',
+     'topographic__elevation',
+     'topographic__steepest_slope']
     """
 
     _name = "FlowDirectorToOne"
@@ -143,6 +146,32 @@ class _FlowDirectorToOne(_FlowDirector):
         """run_one_step is not implemented for this component."""
         raise NotImplementedError("run_one_step()")
 
+    # set properties. These are the same for all DirectToOne Directors
+    # Number of Node
+    @property
+    def node_receiving_flow(self):
+        """Return the node id of the node receiving flow.
+
+        Examples
+        --------
+        >>> from landlab import RasterModelGrid
+        >>> from landlab.components import FlowDirectorSteepest
+        >>> mg = RasterModelGrid((3,3))
+        >>> mg.set_closed_boundaries_at_grid_edges(True, True, True, False)
+        >>> _ = mg.add_field(
+        ...     'topographic__elevation',
+        ...     mg.node_x + mg.node_y,
+        ...     at = 'node'
+        ... )
+        >>> fd = FlowDirectorSteepest(mg, 'topographic__elevation')
+        >>> fd.run_one_step()
+        >>> fd.node_receiving_flow
+        array([0, 1, 2,
+               3, 1, 5,
+               6, 7, 8])
+        """
+        return self._grid["node"]["flow__receiver_node"]
+
 
 if __name__ == "__main__":  # pragma: no cover
     import doctest
