@@ -2,5 +2,4 @@ from .soil_moisture_dynamics import SoilMoisture
 from .infiltrate_soil_green_ampt import SoilInfiltrationGreenAmpt
 
 
-__all__ = ['SoilMoisture',
-           'SoilInfiltrationGreenAmpt', ]
+__all__ = ["SoilMoisture", "SoilInfiltrationGreenAmpt"]
