@@ -24,7 +24,7 @@ class SteepnessFinder(Component):
     >>> from landlab import RasterModelGrid, CLOSED_BOUNDARY
     >>> from landlab.components import FlowAccumulator, FastscapeEroder
     >>> from landlab.components import SteepnessFinder
-    >>> mg = RasterModelGrid((3, 10), (100., 100.))
+    >>> mg = RasterModelGrid((3, 10), xy_spacing=100.)
     >>> for nodes in (mg.nodes_at_right_edge, mg.nodes_at_bottom_edge,
     ...               mg.nodes_at_top_edge):
     ...     mg.status_at_node[nodes] = CLOSED_BOUNDARY
@@ -281,7 +281,7 @@ class SteepnessFinder(Component):
         >>> import numpy as np
         >>> from landlab import RasterModelGrid, CLOSED_BOUNDARY
         >>> from landlab.components import FlowAccumulator
-        >>> mg = RasterModelGrid((4,5), (5., 10.))
+        >>> mg = RasterModelGrid((4,5), xy_spacing=(10., 5.))
         >>> for nodes in (mg.nodes_at_right_edge, mg.nodes_at_bottom_edge,
         ...               mg.nodes_at_top_edge):
         ...     mg.status_at_node[nodes] = CLOSED_BOUNDARY
@@ -328,7 +328,7 @@ class SteepnessFinder(Component):
         >>> import numpy as np
         >>> from landlab import RasterModelGrid, CLOSED_BOUNDARY
         >>> from landlab.components import FlowAccumulator
-        >>> mg = RasterModelGrid((3,10), (5., 10.))
+        >>> mg = RasterModelGrid((3,10), xy_spacing=(10., 5.))
         >>> for nodes in (mg.nodes_at_right_edge, mg.nodes_at_bottom_edge,
         ...               mg.nodes_at_top_edge):
         ...     mg.status_at_node[nodes] = CLOSED_BOUNDARY
@@ -409,7 +409,7 @@ class SteepnessFinder(Component):
         >>> from landlab import RasterModelGrid, CLOSED_BOUNDARY
         >>> from landlab.components import FlowAccumulator
         >>> from landlab.components import SteepnessFinder
-        >>> mg = RasterModelGrid((3,10), (5., 10.))
+        >>> mg = RasterModelGrid((3,10), xy_spacing=(10., 5.))
         >>> for nodes in (mg.nodes_at_right_edge, mg.nodes_at_bottom_edge,
         ...               mg.nodes_at_top_edge):
         ...     mg.status_at_node[nodes] = CLOSED_BOUNDARY
@@ -513,7 +513,7 @@ class SteepnessFinder(Component):
         >>> from landlab import RasterModelGrid, CLOSED_BOUNDARY
         >>> from landlab.components import FlowAccumulator, FastscapeEroder
         >>> from landlab.components import SteepnessFinder
-        >>> mg = RasterModelGrid((5, 5), 100.)
+        >>> mg = RasterModelGrid((5, 5), xy_spacing=100.)
         >>> for nodes in (mg.nodes_at_right_edge, mg.nodes_at_bottom_edge,
         ...               mg.nodes_at_top_edge):
         ...     mg.status_at_node[nodes] = CLOSED_BOUNDARY
