@@ -146,6 +146,9 @@ class VoronoiDelaunayGrid(ModelGrid):
             y-coordinate of points
         reorient_links (optional) : bool
             whether to point all links to the upper-right quadrant
+        xy_of_reference : tuple, optional
+            Coordinate value in projected space of (0., 0.)
+            Default is (0., 0.)
 
         Returns
         -------
@@ -170,6 +173,7 @@ class VoronoiDelaunayGrid(ModelGrid):
         Creates an unstructured grid around the given (x,y) points.
         """
         x, y = np.asarray(x, dtype=float), np.asarray(y, dtype=float)
+
         if x.size != y.size:
             raise ValueError("x and y arrays must have the same size")
 
